# Default descriptors

This folder contains default VNFD and NSD for creating 5GTANGO descriptors or OSM descriptors.

The 5GTANGO default descriptors are usually loaded directly from [tng-schma](https://github.com/sonata-nfv/tng-schema) to obtain the most recent version. By turning off `productionMode` in `generate.js`, the descriptorgen can instead use the default VNFD and NSD here - allowing some adjustments, e.g., for demos or debugging.

The OSM default descriptors are based on examples from the [OSM's website](https://osm.etsi.org/wikipub/index.php/Reference_VNF_and_NS_Descriptors_(Release_THREE)) and [git repository](https://osm.etsi.org/gitweb/?p=osm/devops.git;a=tree;f=descriptor-packages;h=415663e8a79101851d4ae20a23d8ec057bdd3a71;hb=HEAD).

